<?php

namespace Drupal\lb_cards\EventSubscriber;

use Drupal\y_lb\Event\WSStyleGroupAppliesToAlter;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * An event subscriber to alter available WS Style groups for a component.
 */
class WSStyleGroupAlter implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      WSStyleGroupAppliesToAlter::ALTER_APPLIES_TO => 'alterGroups'
    ];
  }

  /**
   * Alter WS Style Groups applies to option for provided component.
   *
   * @param WSStyleGroupAppliesToAlter $event
   *   Event object.
   *
   * @return void
   */
  public function alterGroups(WSStyleGroupAppliesToAlter $event) {
    $component = $event->getComponent();
    $allowed_groups = $this->getAllowedStyleGroups();
    if (!empty($allowed_groups[$component])) {
      $event->setGroups($allowed_groups[$component]);
    }
  }

  /**
   * Get WS Style Groups allowed to the component.
   *
   * @return array[]
   *  Components allowed WS Style Groups.
   */
  protected function getAllowedStyleGroups() {
    return [
      'inline_block:lb_cards' => [
        'border_style_component',
      ],
    ];
  }

}
